@@ -1,6 +1,6 @@
 package MARC::Moose::Record;
 # ABSTRACT: MARC::Moose bibliographic record
-$MARC::Moose::Record::VERSION = '1.0.23';
+$MARC::Moose::Record::VERSION = '1.0.24';
 use Moose;
 
 use Modern::Perl;
@@ -69,6 +69,17 @@ my $parser = {
 }
 
 
+
+sub clone {
+    my $self = shift;
+
+    my $record = MARC::Moose::Record->new();
+    $record->_leader( $self->leader );
+    $record->fields( [ map { $_->clone(); } @{$self->fields} ] );
+    return $record;
+}
+
+
 sub set_leader_length {
     my ($self, $length, $offset) = @_;
 
@@ -197,7 +208,7 @@ MARC::Moose::Record - MARC::Moose bibliographic record
 
 =head1 VERSION
 
-version 1.0.23
+version 1.0.24
 
 =head1 DESCRIPTION
 
@@ -223,6 +234,10 @@ MARC::Moose::Field::Std.
 
 =head1 METHODS
 
+=head2 clone()
+
+Clone the record. Create a new record containing exactly the same data.
+
 =head2 set_leader_length( I<length>, I<offset> )
 
 This method is called to reset leader length of record and offset of data
